==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebNavbarDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebNavbarDescription } from "./WebNavbarDescription";
/**
 * @hidden
 */
export let WebNavbarDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebNavbarDescriptionMetadata extends Base {
        static b(a) {
            if (WebNavbarDescriptionMetadata.a == null) {
                WebNavbarDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebNavbarDescriptionMetadata.c(WebNavbarDescriptionMetadata.a);
            }
            if (a.k(WebNavbarDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebNavbarDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:Navbar");
            a.item("__tagNameWC", "String:igc-navbar");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        }
        static d(a) {
            WebNavbarDescriptionMetadata.b(a);
            a.ac("WebNavbar", () => new WebNavbarDescription());
            a.ab("WebNavbar", WebNavbarDescriptionMetadata.a);
        }
    }
    WebNavbarDescriptionMetadata.$t = /*@__PURE__*/ markType(WebNavbarDescriptionMetadata, 'WebNavbarDescriptionMetadata');
    WebNavbarDescriptionMetadata.a = null;
    return WebNavbarDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/WebNavbarDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebNavbarDescription } from "./WebNavbarDescription";
/**
 * @hidden
 */
export let WebNavbarDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebNavbarDescriptionMetadata extends Base {
        static b(a) {
            if (WebNavbarDescriptionMetadata.a == null) {
                WebNavbarDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebNavbarDescriptionMetadata.c(WebNavbarDescriptionMetadata.a);
            }
            if (a.k(WebNavbarDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebNavbarDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:Navbar");
            a.item("__tagNameWC", "String:igc-navbar");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        }
        static d(a) {
            WebNavbarDescriptionMetadata.b(a);
            a.ae("WebNavbar", () => new WebNavbarDescription());
            a.ad("WebNavbar", WebNavbarDescriptionMetadata.a);
        }
    }
    WebNavbarDescriptionMetadata.$t = /*@__PURE__*/ markType(WebNavbarDescriptionMetadata, 'WebNavbarDescriptionMetadata');
    WebNavbarDescriptionMetadata.a = null;
    return WebNavbarDescriptionMetadata;
})();
